% greek-euenc.def
% +++++++++++++++
%
% Backwards compatibility file loading tuenc-greek.def.
%
% :Copyright: © 2020 Günter Milde
% :Licence:   This work may be distributed and/or modified under the
%             conditions of the `LaTeX Project Public License`_, either
%             version 1.3 of this license or any later version.

\ProvidesFile{greek-euenc.def}
[2020/10/30 2.0 Greek LICRs for XeTeX and LuaTeX]

% Just in case there is an old fontspec using EU1 or EU2::

\ifdefined \UTFencname % set by fontspec
    \providecommand*{\UnicodeEncodingName}{\UTFencname} % TU, EU1, or EU2
\fi

\input{tuenc-greek.def}
